==> tuia-news-center-api-0.0.65_zwb1-20180906.103947-1-sources.jar: cn/com/duiba/tuia/news/center/dto/firstscreen/OwnAdvertDto.java <==
package cn.com.duiba.tuia.news.center.dto.firstscreen;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * Created by zhou_wb on 2018/9/6.
 */
public class OwnAdvertDto implements Serializable{

    private Long id;

    /**
     * 广告标题
     */
    private String title;

    /**
     * 广告优先级
     */
    private Integer advertSort;

    /**
     * 广告链接
     */
    private String advertUrl;

    /**
     * 包名
     */
    private String packageName;

    /**
     * ios专用类似于包名
     */
    private String bundleId;

    /**
     * 上限
     */
    private Integer upperLimit;

    /**
     * 投放开始时间
     */
    private Date launchStart;

    /**
     * 投放结束时间
     */
    private Date launchEnd;

    /**
     * 计费类型 1：CPM: 按（千次）展示计费 2:CPC: 按点击计费  3:CPT: 按时段计费
     */
    private Integer chargeType;

    /**
     * 计价价格（分）
     */
    private Long advertPrice;

    /**
     * 是否启用
     */
    private Integer enableStatus;

    /**
     * 是否活跃拉伸
     */
    private Integer enableActive;

    /**
     * 创建时间
     */
    private Date gmtCreate;


    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public Integer getAdvertSort() {
        return advertSort;
    }

    public void setAdvertSort(Integer advertSort) {
        this.advertSort = advertSort;
    }

    public String getAdvertUrl() {
        return advertUrl;
    }

    public void setAdvertUrl(String advertUrl) {
        this.advertUrl = advertUrl;
    }

    public String getPackageName() {
        return packageName;
    }

    public void setPackageName(String packageName) {
        this.packageName = packageName;
    }

    public String getBundleId() {
        return bundleId;
    }

    public void setBundleId(String bundleId) {
        this.bundleId = bundleId;
    }

    public Integer getUpperLimit() {
        return upperLimit;
    }

    public void setUpperLimit(Integer upperLimit) {
        this.upperLimit = upperLimit;
    }

    public Date getLaunchStart() {
        return launchStart;
    }

    public void setLaunchStart(Date launchStart) {
        this.launchStart = launchStart;
    }

    public Date getLaunchEnd() {
        return launchEnd;
    }

    public void setLaunchEnd(Date launchEnd) {
        this.launchEnd = launchEnd;
    }

    public Integer getChargeType() {
        return chargeType;
    }

    public void setChargeType(Integer chargeType) {
        this.chargeType = chargeType;
    }

    public Long getAdvertPrice() {
        return advertPrice;
    }

    public void setAdvertPrice(Long advertPrice) {
        this.advertPrice = advertPrice;
    }

    public Integer getEnableStatus() {
        return enableStatus;
    }

    public void setEnableStatus(Integer enableStatus) {
        this.enableStatus = enableStatus;
    }

    public Integer getEnableActive() {
        return enableActive;
    }

    public void setEnableActive(Integer enableActive) {
        this.enableActive = enableActive;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }
}

==> tuia-news-center-api-1.6.6.0-zwb6-20181129.071045-1-sources.jar: cn/com/duiba/tuia/news/center/dto/firstscreen/OwnAdvertDto.java <==
package cn.com.duiba.tuia.news.center.dto.firstscreen;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * Created by zhou_wb on 2018/9/6.
 */
public class OwnAdvertDto implements Serializable{

    private Long id;

    /**
     * 广告标题
     */
    private String title;

    /**
     * 广告优先级
     */
    private Integer advertSort;

    /**
     * 广告链接
     */
    private String advertUrl;

    /**
     * 广告图片
     */
    private String advertImg;

    /**
     * 包名
     */
    private String packageName;

    /**
     * ios专用类似于包名
     */
    private String bundleId;

    /**
     * 上限
     */
    private Integer upperLimit;

    /**
     * 投放开始时间
     */
    private Date launchStart;

    /**
     * 投放结束时间
     */
    private Date launchEnd;

    /**
     * 计费类型 1：CPM: 按（千次）展示计费 2:CPC: 按点击计费  3:CPT: 按时段计费
     */
    private Integer chargeType;

    /**
     * 计价价格（分）
     */
    private Long advertPrice;

    /**
     * 是否启用
     */
    private Integer enableStatus;

    /**
     * 是否活跃拉伸
     */
    private Integer enableActive;

    /**
     * 创建时间
     */
    private Date gmtCreate;


    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public Integer getAdvertSort() {
        return advertSort;
    }

    public void setAdvertSort(Integer advertSort) {
        this.advertSort = advertSort;
    }

    public String getAdvertUrl() {
        return advertUrl;
    }

    public void setAdvertUrl(String advertUrl) {
        this.advertUrl = advertUrl;
    }

    public String getPackageName() {
        return packageName;
    }

    public void setPackageName(String packageName) {
        this.packageName = packageName;
    }

    public String getBundleId() {
        return bundleId;
    }

    public void setBundleId(String bundleId) {
        this.bundleId = bundleId;
    }

    public Integer getUpperLimit() {
        return upperLimit;
    }

    public void setUpperLimit(Integer upperLimit) {
        this.upperLimit = upperLimit;
    }

    public Date getLaunchStart() {
        return launchStart;
    }

    public void setLaunchStart(Date launchStart) {
        this.launchStart = launchStart;
    }

    public Date getLaunchEnd() {
        return launchEnd;
    }

    public void setLaunchEnd(Date launchEnd) {
        this.launchEnd = launchEnd;
    }

    public Integer getChargeType() {
        return chargeType;
    }

    public void setChargeType(Integer chargeType) {
        this.chargeType = chargeType;
    }

    public Long getAdvertPrice() {
        return advertPrice;
    }

    public void setAdvertPrice(Long advertPrice) {
        this.advertPrice = advertPrice;
    }

    public Integer getEnableStatus() {
        return enableStatus;
    }

    public void setEnableStatus(Integer enableStatus) {
        this.enableStatus = enableStatus;
    }

    public Integer getEnableActive() {
        return enableActive;
    }

    public void setEnableActive(Integer enableActive) {
        this.enableActive = enableActive;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public String getAdvertImg() {
        return advertImg;
    }

    public void setAdvertImg(String advertImg) {
        this.advertImg = advertImg;
    }
}
